@@ -1,7 +1,8 @@
 #!/usr/bin/env python3 -i
-# Copyright 2019-2020 Collabora, Ltd
+# Copyright 2019-2024, Collabora, Ltd. and the xr-hardware contributors
 # SPDX-License-Identifier: BSL-1.0
-# Author: Ryan Pavlik <ryan.pavlik@collabora.com>
+#
+# Original Author: Rylie Pavlik <rylie.pavlik@collabora.com>
 """XR Hardware device database."""
 
 from .device import Device
@@ -72,6 +73,10 @@ def get_devices():
         Device("Sony PlayStation Move Motion Controller CECH-ZCM2",
                "054c", "0c5e", bluetooth=True, usb=True),
 
+        Device("Sony PlayStation VR2", "054c", "0cde"),
+        Device("Sony PlayStation VR2 Sensor Controller",
+               "054c", "0e46", bluetooth=True, usb=True),
+
         #
         Device("LG 360 VR R-100", "1004", "6374"),
 
@@ -91,16 +96,28 @@ def get_devices():
         #
         # Windows Mixed Reality headsets
         Device("Microsoft HoloLens Sensors", "045e", "0659"),
+        Device("Samsung Odyssey sensors", "04e8", "7310"),
         Device("Samsung Odyssey+ sensors", "04e8", "7312"),
         Device("HP VR1000", "03f0", "0367"),
         Device("HP Reverb G1", "03f0", "0c6a"),
         Device("HP Reverb G2", "03f0", "0580"),
         Device("Lenovo QHMD", "17ef", "b801"),
-        Device("Cypress Semiconductor Corp. Lenovo Explorer", "04b4", "6504"),
+        # At least Lenovo and Dell
+        Device("Cypress Semiconductor Corp. (Various WMR)", "04b4", "6504"),
+        Device("Acer AH100 QHMD", "0502", "b0d6"),
+        Device("Dell Visor VR118", "413c", "b0d5"),
         # Quanta QHMD == Medion Erazer X1000
         Device("Medion Erazer X1000", "0408", "b5d5"),
 
         #
         Device("Vis3r NxtVR", "1209", "9d0f"),
+
+        #
+        # Xreal glasses
+        Device("Xreal Light Microcontroller", "0486", "573c"),
+        Device("Xreal Light OV580", "05a9", "0680"),
+        Device("Xreal Air", "3318", "0424"),
+        Device("Xreal Air 2", "3318", "0428"),
+        Device("Xreal Air 2 Pro", "3318", "0432")
     )
 # fmt: on
